#!/usr/bin/env node

/**
 * Tmplify prototype.
 */

'use strict'

process.chdir(`${__dirname}/..`)

const path = require('path')
const fs = require('fs')
const { runTasks } = require('ape-tasking')
const tmplconv = require('tmplconv')

const scff = require('../lib')

let demo = path.dirname(require.resolve('apeman-demo-scff/package.json'))
let demoPkg = require('apeman-demo-scff/package.json')

runTasks('tmplify', [
  () => tmplconv.tmplify(demo, 'asset/tmpl', {
    clean: true,
    mode: '444',
    pattern: [
      '+(lib|test)/.*.bud',
      '+(lib|test)/.*.hbs',
      '**/*.*',
      '.*'
    ],
    ignore: [
      '.DS_Store',
      '.svg',
      'node_modules/**/*.*',
      'node_modules/**/.*',
      'asset/tmpl',
      'lib/index.js',
      'README.md',
      'LICENSE'
    ],
    data: {
      repository: 'apeman-demo-labo/apeman-demo-scff',
      package_name: demoPkg.name,
      package_description: demoPkg.description,
      author_name: demoPkg.author.name,
      author_email: demoPkg.author.email,
      author_url: demoPkg.author.url,
      demo_package: 'apeman-demo-demo'
    },
    prefix: scff.prefix,
    suffix: scff.suffix
  }),
  () => tmplconv.tmplify(`${__dirname}/..`, 'asset/tmpl', {
    pattern: [
      '.gitignore'
    ],
    prefix: scff.prefix,
    suffix: scff.suffix
  }),
  () => {
    let filename = require.resolve('../asset/tmpl/package.json.tmpl')
    let str = fs.readFileSync(filename).toString()
    let pkg = JSON.parse(str)
    fs.chmodSync(filename, '644')
    fs.writeFileSync(filename, JSON.stringify({
      name: pkg.name,
      version: '1.0.0',
      description: pkg.description,
      main: pkg.main,
      scripts: pkg.scripts,
      repository: pkg.repository.url.split(/\//g).slice(-1).join('/').replace(/\.git$/, ''),
      keywords: pkg.keywords,
      author: pkg.author,
      license: pkg.license,
      bugs: pkg.bugs,
      homepage: pkg.homepage,
      dependencies: pkg.dependencies,
      devDependencies: pkg.devDependencies,
      engines: pkg.engines
    }, null, 2))
    fs.chmodSync(filename, '444')
  }
], true)
